aboutsummaryrefslogtreecommitdiffhomepage
path: root/tensorflow/contrib/lite/simple_memory_arena.h
diff options
context:
space:
mode:
authorGravatar A. Unique TensorFlower <gardener@tensorflow.org>2018-03-15 15:44:56 -0700
committerGravatar TensorFlower Gardener <gardener@tensorflow.org>2018-03-15 15:49:01 -0700
commit1e75c69339da2fbf2c5c5fbeb891243badae7ff8 (patch)
tree81268169bbff6836bfbbd4e9866a1374f597a624 /tensorflow/contrib/lite/simple_memory_arena.h
parent6c62e650252ab32f83637a8de6720e73ffeca226 (diff)
Automated g4 rollback of changelist 189231636
PiperOrigin-RevId: 189258641
Diffstat (limited to 'tensorflow/contrib/lite/simple_memory_arena.h')
-rw-r--r--tensorflow/contrib/lite/simple_memory_arena.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/tensorflow/contrib/lite/simple_memory_arena.h b/tensorflow/contrib/lite/simple_memory_arena.h
index 5faf78b59e..0535522374 100644
--- a/tensorflow/contrib/lite/simple_memory_arena.h
+++ b/tensorflow/contrib/lite/simple_memory_arena.h
@@ -22,7 +22,7 @@ limitations under the License.
namespace tflite {
// This little structure holds the offset and the size for a dynamic memory
// allocation in the memory arena. When the arena is committed and the
// underlying buffer is set, the alloc can be resolved into an actual memory
// pointer.
struct ArenaAlloc {
@@ -43,7 +43,7 @@ struct ArenaAlloc {
class SimpleMemoryArena {
public:
explicit SimpleMemoryArena(size_t arena_alignment)
- : committed_(false),
+ : commited_(false),
arena_alignment_(arena_alignment),
high_water_mark_(0),
underlying_buffer_size_(0),
@@ -73,7 +73,7 @@ class SimpleMemoryArena {
}
private:
- bool committed_;
+ bool commited_;
size_t arena_alignment_;
size_t high_water_mark_;
std::unique_ptr<char[]> underlying_buffer_;
@@ -22,7 +22,7 @@ limitations under the License.
namespace tflite {
// This little structure holds the offset and the size for a dynamic memory
-// allocation in the memory arena. When the arena is committed and the
+// allocation in the memory arena. When the arena is commited and the
// underlying buffer is set, the alloc can be resolved into an actual memory
// pointer.